summaryrefslogtreecommitdiff
path: root/nuttx/arch/arm/src/str71x/str71x_head.S
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/arch/arm/src/str71x/str71x_head.S')
-rw-r--r--nuttx/arch/arm/src/str71x/str71x_head.S12
1 files changed, 6 insertions, 6 deletions
diff --git a/nuttx/arch/arm/src/str71x/str71x_head.S b/nuttx/arch/arm/src/str71x/str71x_head.S
index e83affa37..710fd57a5 100644
--- a/nuttx/arch/arm/src/str71x/str71x_head.S
+++ b/nuttx/arch/arm/src/str71x/str71x_head.S
@@ -599,7 +599,7 @@ dtor_end:
* _ebss is the end of the BSS regsion (see ld.script)
* The idle task stack starts at the end of BSS and is
* of size CONFIG_IDLETHREAD_STACKSIZE. The heap continues
* from there until the end of memory. See g_heapbase
* below.
*/
@@ -612,18 +612,18 @@ LC2: .long _eronly /* Where .data defaults are stored in FLASH */
.long _edata
.size __start, .-__start
/* This global variable is unsigned long g_heapbase and is
* exported from here only because of its coupling to LCO
* above.
*/
.data
.align 4
- .globl g_heapbase
- .type g_heapbase, object
-g_heapbase:
+ .globl g_idle_topstack
+ .type g_idle_topstack, object
+g_idle_topstack:
.long _ebss+CONFIG_IDLETHREAD_STACKSIZE
- .size g_heapbase, .-g_heapbase
+ .size g_idle_topstack, .-g_idle_topstack
.end
@@ -599,7 +599,7 @@ dtor_end:
* The idle task stack starts at the end of BSS and is
* of size CONFIG_IDLETHREAD_STACKSIZE. The heap continues
- * from there until the end of memory. See g_heapbase
+ * from there until the end of memory. See g_idle_topstack
* below.
*/
@@ -612,18 +612,18 @@ LC2: .long _eronly /* Where .data defaults are stored in FLASH */
.long _edata
.size __start, .-__start
- /* This global variable is unsigned long g_heapbase and is
+ /* This global variable is unsigned long g_idle_topstack and is
* exported from here only because of its coupling to LCO
* above.